#include "App.h"
/* ****************************************************************************
 * App Contructor
 */
App::App(const Wt::WEnvironment& env) : Wt::WApplication(env)
{
    messageResourceBundle().use(appRoot() + "audio", false);
    Wt::WBootstrapTheme* bootstrapTheme = new Wt::WBootstrapTheme();
    bootstrapTheme->setVersion(Wt::WBootstrapTheme::Version3);
    setTheme(bootstrapTheme);

    internalPathChanged().connect(this, &App::logInternalPath);

    create_menu();
}
/* ****************************************************************************
 * create_menu
 */
void App::create_menu()
{
    Wt::WTemplate* result = new Wt::WTemplate(Wt::WString::tr("template"), root()); //  <message id="template">
    homePage_ = result;
    //
    Wt::WStackedWidget *contents = new Wt::WStackedWidget();
    Wt::WAnimation fade(Wt::WAnimation::Fade, Wt::WAnimation::Linear, 250);
    contents->setTransitionAnimation(fade);
    contents->setId("main_page");
    // Create a navigation bar with a link to a web page.
    Wt::WNavigationBar* navigation = new Wt::WNavigationBar(contents);
    navigation->setTitle("Witty Wizard");

    Wt::WStackedWidget* contentsStack = new Wt::WStackedWidget(contents);
    //contentsStack->setId("contents");
    contentsStack->addStyleClass("contents");

    // Setup a Main menu.
    Wt::WMenu* mainMenu_ = new Wt::WMenu(contentsStack, contents);
    mainMenu_->setId("mainmenu");
    navigation->addMenu(mainMenu_);
    // Add two menu items for example
    mainMenu_->addItem(Wt::WString::tr("static"),  Statically())->setPathComponent("");
    mainMenu_->addItem(Wt::WString::tr("audio"),   deferCreate(boost::bind(&App::Audio, this)));

    contents->addWidget(contentsStack);

    // Make the menu is internal-path aware.
    mainMenu_->setInternalPathEnabled("/");
    // Bind to Template
    result->bindWidget("menu", navigation);
    result->bindWidget("contents", contents);
}
/* ****************************************************************************
 * Statically
 */
Wt::WWidget* App::Statically()
{
    return new Wt::WText(Wt::WString::tr("static.intro"));
}
/* ****************************************************************************
 * Audio
 */
Wt::WWidget* App::Audio()
{
    AudioManView* thisAudio = new AudioManView("/audio/");
    thisAudio->setObjectName("audioman");
    return thisAudio;
}
/* ****************************************************************************
 * logInternalPath
 */
void App::logInternalPath(const std::string& path)
{
    // simulate an access log for the interal paths
    log("Path Change") << path;
}
// --- End Of File ------------------------------------------------------------
