#ifndef APP_H
#define APP_H
#include <iostream>
#include <fstream>
#include <boost/lexical_cast.hpp>
#include <boost/tokenizer.hpp>
#include <boost/algorithm/string.hpp>
#include <Wt/WApplication>
#include <Wt/WEnvironment>
#include <Wt/WContainerWidget>
#include <Wt/WMenu>
#include <Wt/WMenuItem>
#include <Wt/WPopupMenu>
#include <Wt/WStackedWidget>
#include <Wt/WText>
#include <Wt/WBootstrapTheme>
#include <Wt/WTemplate>
#include <Wt/WNavigationBar>
#include <Wt/WComboBox>
#include <Wt/WVideo>
#include <Wt/WImage>
#include <Wt/WLineEdit>
#include <Wt/WAudio>
#include "view/AudioManView.h"
/* ****************************************************************************
 * Deferred Widget
 * A utility container widget which defers creation of its single
 * child widget until the container is loaded (which is done on-demand by a WMenu).
 * The constructor takes the create function for the widget as a parameter.
 *
 * We use this to defer widget creation until needed.
 */
template <typename Function>
class DeferredWidget : public Wt::WContainerWidget
{
    public:
        DeferredWidget(Function f) : f_(f) { }

    private:
        void load()
        {
            Wt::WContainerWidget::load();
            if (count() == 0)
            {
                addWidget(f_());
            }
        }

        Function f_;
}; // end class DeferredWidget
/* ****************************************************************************
 * defer Create
 */
template <typename Function>
DeferredWidget<Function>* deferCreate(Function f)
{
    return new DeferredWidget<Function>(f);
} // end deferCreate
/* ****************************************************************************
 * App
 */
class App : public Wt::WApplication
{
    public:
        App(const Wt::WEnvironment& e);
    private:
        Wt::WWidget* homePage_;
        void create_menu();
        Wt::WWidget* Statically();
        Wt::WWidget* Audio();
        void logInternalPath(const std::string& path);
};
#endif // APP_H
// --- End Of File ------------------------------------------------------------
