/* ****************************************************************************
 * Audio Man Implementation
 */
#include "AudioManImpl.h"
/* ****************************************************************************
 * Audio Man Impl
 */
AudioManImpl::AudioManImpl(const std::string& basePath) : basePath_(basePath)
{
    audioItems = new Wt::WContainerWidget(this);
    //
    items_ = new Wt::WContainerWidget(this);

    cb = new Wt::WComboBox(items_);
    cb->addItem("1");
    cb->addItem("2");
    cb->addItem("10");
    cb->addItem("100");
    cb->setCurrentIndex(0);
    cb->activated().connect(this, &AudioManImpl::ComboboxChanged);
    items_->addWidget(CreateAudio(1)); // audioItems did not work, but clearing items_ removes WComboBox
    //
}
/* ****************************************************************************
 * ~Audio Man Impl
 */
AudioManImpl::~AudioManImpl()
{
    clear();
} // end ~AudioManImpl
/* ****************************************************************************
 * ComboboxChanged
 */
void AudioManImpl::ComboboxChanged()
{
    switch(cb->currentIndex())
    {
        case 0:
            CreateAudio(1);
            break;
        case 1:
            CreateAudio(2);
            break;
        case 2:
            CreateAudio(10);
            break;
        case 3:
            CreateAudio(100);
            break;
    }
}
/* ****************************************************************************
 * Create Audio
 */
Wt::WWidget* AudioManImpl::CreateAudio(int number)
{
    audioItems->clear();
    TextPageBottomDiv = "";
    /*
     * useTemplate | useTemplateData | useWidgetFun | useWraper | Pass | Description
     *     T       |        0        |    0         |    F      |  F   | Template - tag      - registerType & addFunction external
     *     T       |        0        |    0         |    T      |  F   | Template - tag      - Wraper - registerType & addFunction external - Note: theme for Flash is not working
     *     T       |        0        |    1         |    F      |  F   | Template - tag      - setTemplate (no type registered: audio)
     *     T       |        0        |    2         |    F      |  T   | Template - tag      - WText (${widget:audio id='audio0' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3' altsrc='/resources/LaSera-NeverComeAround.mp3' title='La Sera - Never Come Around'})
     *     T       |        1        |    2         |    F      |  T   | Template - HTML5    - WText
     *     T       |        2        |    0         |    F      |  F   | Template - Full tag - registerType & addFunction external
     *     T       |        2        |    0         |    T      |  F   | Template - Full tag - Wraper - registerType & addFunction external - Note: theme for Flash is not working
     *     F       |        NA       |    NA        |    NA     |  T   | Use Audio player directly
    */
    useTemplate = true;  // true uses WidgetFunction, false creates WAudio controls
    useTemplateData = 4; // 0 = single binding, 1 = single html5 tag, 2 = multiple bindings, 3 = mutiple html5 tags
    useWidgetFun = 0;    // 0 = working WidgetFunction, 1 = broke WidgetFunction, 2 = WContainerWidget WText wraper for HTML
    bool useWraper = false;
    for (int i = 0; i < number; i++)
    {
        if (useTemplate)
        {
            if (useTemplateData == 0)
            {
                // Test useTemplateData = 0 And useWidgetFun = 0, fails with useWraper true or false, but loses Flash audio theme in true in browsers with no html5 audio support
                // html with WidgetFunction binding for aduio
                TextPageBottomDiv += "${widget:audio id='audio" + std::to_string(i) + "' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3' altsrc='/resources/LaSera-NeverComeAround.mp3' title='La Sera - Never Come Around'}<br />";
            }
            if (useTemplateData == 1)
            {
                // Test useTemplateData = 1 And useWidgetFun = 2, works with useWraper true or false, but loses Flash audio theme in true in browsers with no html5 audio support
                // normal html5 audio controls
                TextPageBottomDiv += "<audio controls='controls' id='audio" + std::to_string(i) + "' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio><br />";
            }
            if (useTemplateData == 2)
            {
                // Test useTemplateData = 2 And useWidgetFun = 0, fails with useWraper true or false, but loses Flash audio theme in true in browsers with no html5 audio support
                // html with WidgetFunction binding for aduio
                TextPageBottomDiv += "<p>&nbsp;</p> <div id='vlink' style='text-align: center; margin: 0 auto;'> Text...<br /> More.<br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Another License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>And Another</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Last License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Ok, just one more</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>This is the last one</a> </div><hr /><p>&nbsp;</p><h1 style='text-align: center; margin: 0 auto;'>Text<br />And More Text</h1><p>&nbsp;</p><hr /><p>&nbsp;</p><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-1<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-1' /><br />${widget:audio id='audio1' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-2<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-2' /><br />${widget:audio id='audio2' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-3<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-3' /><br />${widget:audio id='audio3' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-4<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-4' /><br />${widget:audio id='audio4' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-5<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-5' /><br />${widget:audio id='audio5' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-6<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-6' /><br />${widget:audio id='audio6' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-7<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-7' /><br />${widget:audio id='audio7' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-8<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-8' /><br />${widget:audio id='audio8' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-9<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-9' /><br />${widget:audio id='audio9' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-10<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-10' /><br />${widget:audio id='audio10' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-11<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-11' /><br />${widget:audio id='audio11' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-12<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-12' /><br />${widget:audio id='audio12' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-13<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-13' /><br />${widget:audio id='audio13' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-14<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-14' /><br />${widget:audio id='audio14' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-15<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-15' /><br />${widget:audio id='audio15' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-16<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-16' /><br />${widget:audio id='audio16' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-17<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-17' /><br />${widget:audio id='audio17' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-18<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-18' /><br />${widget:audio id='audio18' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-19<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-19' /><br />${widget:audio id='audio19' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-20<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-20' /><br />${widget:audio id='audio20' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-21<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-21' /><br />${widget:audio id='audio21' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-22<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-22' /><br />${widget:audio id='audio22' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-23<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-23' /><br />${widget:audio id='audio23' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-24<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-24' /><br />${widget:audio id='audio24' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-25<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-25' /><br />${widget:audio id='audio25' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-26<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-26' /><br />${widget:audio id='audio26' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-27<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-27' /><br />${widget:audio id='audio27' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-28<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-28' /><br />${widget:audio id='audio28' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-29<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-29' /><br />${widget:audio id='audio29' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>How do yew teach someone something that they already know how to do?<br /><br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-30<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-30' /><br />${widget:audio id='audio30' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-31<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-31' /><br />${widget:audio id='audio31' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-32<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-32' /><br />${widget:audio id='audio32' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-33<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-33' /><br />${widget:audio id='audio33' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-34<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-34' /><br />${widget:audio id='audio34' class='wtaudio' type='audio/mpeg' width='580' height='33' src='/resources/LaSera-NeverComeAround.mp3'}</div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><p>&nbsp;</p>";
            }
            if (useTemplateData == 3)
            {
                // Test useTemplateData = 3 And useWidgetFun = 2, works with useWraper true or false
                // normal html5 audio controls
                TextPageBottomDiv += "<p>&nbsp;</p> <div id='vlink' style='text-align: center; margin: 0 auto;'> Text...<br /> More.<br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Another License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>And Another</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Last License</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>Ok, just one more</a> <br /> <a style='text-align: center; margin: 0 auto;' href='/resources/font-awesome/LICENSE.txt' target='_blank' title='Right Click: Save Link As...'>This is the last one</a> </div><hr /><p>&nbsp;</p><h1 style='text-align: center; margin: 0 auto;'>Text<br />And More Text</h1><p>&nbsp;</p><hr /><p>&nbsp;</p><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-1<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-1' /><br /><audio controls='controls' id='audio1' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-2<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-2' /><br /><audio controls='controls' id='audio2' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-3<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-3' /><br /><audio controls='controls' id='audio3' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-4<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-4' /><br /><audio controls='controls' id='audio4' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-5<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-5' /><br /><audio controls='controls' id='audio5' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-6<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-6' /><br /><audio controls='controls' id='audio6' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-7<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-7' /><br /><audio controls='controls' id='audio7' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-8<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-8' /><br /><audio controls='controls' id='audio8' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-9<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-9' /><br /><audio controls='controls' id='audio9' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-10<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-10' /><br /><audio controls='controls' id='audio10' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-11<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-11' /><br /><audio controls='controls' id='audio11' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-12<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-12' /><br /><audio controls='controls' id='audio12' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-13<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-13' /><br /><audio controls='controls' id='audio13' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-14<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-14' /><br /><audio controls='controls' id='audio14' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-15<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-15' /><br /><audio controls='controls' id='audio15' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-16<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-16' /><br /><audio controls='controls' id='audio16' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-17<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-17' /><br /><audio controls='controls' id='audio17' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-18<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-18' /><br /><audio controls='controls' id='audio18' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-19<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-19' /><br /><audio controls='controls' id='audio19' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-20<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-20' /><br /><audio controls='controls' id='audio20' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-21<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-21' /><br /><audio controls='controls' id='audio21' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-22<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-22' /><br /><audio controls='controls' id='audio22' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-23<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-23' /><br /><audio controls='controls' id='audio23' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-24<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-24' /><br /><audio controls='controls' id='audio24' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-25<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-25' /><br /><audio controls='controls' id='audio25' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-26<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-26' /><br /><audio controls='controls' id='audio26' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-27<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-27' /><br /><audio controls='controls' id='audio27' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-28<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-28' /><br /><audio controls='controls' id='audio28' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-29<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-29' /><br /><audio controls='controls' id='audio29' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>How do yew teach someone something that they already know how to do?<br /><br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-30<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-30' /><br /><audio controls='controls' id='audio30' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-31<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-31' /><br /><audio controls='controls' id='audio31' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-32<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-32' /><br /><audio controls='controls' id='audio32' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-33<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-33' /><br /><audio controls='controls' id='audio33' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><hr /><div style='text-align: center; margin: 0 auto;'><p>&nbsp;</p>Scene 0-34<p>&nbsp;</p><img src='/resources/icons/blue-pill-small.png' width='580' height='326' alt='Scene 0-34' /><br /><audio controls='controls' id='audio34' class='wtaudio' width='580' height='33'> <source src='/resources/LaSera-NeverComeAround.mp3'</source></audio></div><p>&nbsp;</p><p style='text-align: center; margin: 0 auto;'>The Scene, some text <br /></p><p>&nbsp;</p>";
            }
            if (useTemplateData == 4)
            {
                // Test useTemplateData = 0 And useWidgetFun = 0, fails with useWraper true or false, but loses Flash audio theme in true in browsers with no html5 audio support
                // html with WidgetFunction binding for aduio
                TextPageBottomDiv += std::to_string(i) + ". Line Edit: ${widget:line-edit id='line-edit" + std::to_string(i) + "' class='wt-line-edit' type='editor' } <br />";
            }
            // <audio id="odqxk2i" controls="controls" name="odqxk2i" onerror="if(event.target.error &amp;&amp; event.target.error.code==event.target.error.MEDIA_ERR_SRC_NOT_SUPPORTED){while (this.hasChildNodes())if (Wt3_3_3.hasTag(this.firstChild,'SOURCE')){this.removeChild(this.firstChild);}else{this.parentNode.insertBefore(this.firstChild, this);}this.style.display= 'none';}" preload="auto"><span id="odqxk2j">??videoman-audio-support??</span><source id="odqxk2is0" onerror="var media = this.parentNode;if(media){while (media &amp;&amp; media.children.length)if (Wt3_3_3.hasTag(media.firstChild,'SOURCE')){media.removeChild(media.firstChild);}else{media.parentNode.insertBefore(media.firstChild, media);}media.style.display= 'none';}" src="/resources/LaSera-NeverComeAround.mp3"></audio>
        }
        else
        {
            Wt::WAudio* audio = new Wt::WAudio(audioItems);
            audio->setId("audio" + std::to_string(i));
            audio->addSource(Wt::WLink(Wt::WApplication::resourcesUrl() + "LaSera-NeverComeAround.mp3"));
            audio->setOptions(Wt::WAudio::Controls);
            audio->setAlternativeContent(new Wt::WText(Wt::WString::tr("Browser-No-Audio-Support")));
            new Wt::WText("<br />", audioItems);
        }
    }
    if (useTemplate)
    {
        if (useWraper)
        {
            audioItems->addWidget(WrapView(&AudioManImpl::GetTemplate)); // useTemplate and !useWidgetFun
        }
        else
        {
            audioItems->addWidget(GetTemplate()); // useTemplate and !useWidgetFun
        }
    }
    return audioItems;
} // end CreateAudio
/* ****************************************************************************
 * Get Template
 *
 */
Wt::WWidget* AudioManImpl::GetTemplate()
{
    if (useWidgetFun == 0)
    {
        //
        bool tagFound = false;
        Wt::WTemplate* myTemplate = new Wt::WTemplate(TextPageBottomDiv);
        if (TextPageBottomDiv.toUTF8().find("widget:audio") != std::string::npos)
        {
            Wt::log("notice") << " AudioManImpl::GetTemplate() found audio tag: useWidgetFun == 0";
            widgetFunction.registerType("audio", WidgetFunction::createAudio);
            // FIXME: Define Default theme
            Wt::WApplication::instance()->useStyleSheet(Wt::WApplication::resourcesUrl() + "jPlayer/skin/jplayer.blue.monday.css");
            tagFound = true;
        }
        if (TextPageBottomDiv.toUTF8().find("widget:line-edit") != std::string::npos)
        {
            Wt::log("notice") << " AudioManImpl::GetTemplate() found line-edit tag: useWidgetFun == 0";
            widgetFunction.registerType("line-edit", WidgetFunction::createLineEdit);
            tagFound = true;
        }
        if (tagFound)
        {
            myTemplate->addFunction("widget", widgetFunction);
        }
        return myTemplate;
    }
    else if (useWidgetFun == 1)
    {
        // This is so much cleaner, since we need to add more controls
        // I pass in referance to widgetFunction, this is not writen as a singleton
        widgetFunction.setTemplate(TextPageBottomDiv, widgetFunction);
        return widgetFunction.getTemplate();
    }
    else
    {
        Wt::log("notice") << " AudioManImpl::GetTemplate() found audio tag: useWidgetFun > 1";
        //
        Wt::WContainerWidget* result = new Wt::WContainerWidget();
        if (!TextPageBottomDiv.empty())
        {
            Wt::WText *w = new Wt::WText(TextPageBottomDiv, Wt::XHTMLUnsafeText, result);
            w->setInternalPathEncoding(true);
        }
        return result;
    }
} // end GetTemplate
/* ****************************************************************************
 * Wrap View
 */
Wt::WWidget* AudioManImpl::WrapView(Wt::WWidget *(AudioManImpl::*createWidget)())
{
    return makeStaticModel(boost::bind(createWidget, this));
} // end WrapView
/* ****************************************************************************
 * set Internal Base Path
 */
void AudioManImpl::SetInternalBasePath(const std::string& basePath)
{
    basePath_ = basePath;
    refresh();
} // end void SetInternalBasePath
/* ****************************************************************************
 * refresh
 */
void AudioManImpl::refresh()
{
    //HandlePathChange(wApp->internalPath());
} // end void refresh()
// --- End Of File ------------------------------------------------------------
